<?php

/**
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
} // Exit if accessed directly

if( !class_exists( 'denves_lite_admin_notice' ) ) {

	class denves_lite_admin_notice {

		/**
		 * Constructor
		 */

		public function __construct( $fields = array() ) {

			if (
				!get_option( 'denves-lite-is-dismissed-admin-notice') &&
				version_compare( PHP_VERSION, DENVES_LITE_MIN_PHP_VERSION, '>=' )
			) {

				add_action( 'admin_notices', array(&$this, 'admin_notice') );
				add_action( 'admin_head', array( $this, 'dismiss' ) );
				add_action( 'admin_init', array(&$this, 'add_script') ,11);

            }

		}
        
		 /**
		 * Loads the notice style
		 */

		public function add_script() {

			global $wp_version;

			$file_dir = get_template_directory_uri() . '/core/admin/assets/';
			wp_enqueue_style ( 'denves-lite-notice', $file_dir.'css/notice.css' );

		}
        
        /**
		 * Dismiss notice.
		 */

		public function dismiss() {

			if ( isset( $_GET['denves-lite-dismiss'] ) && check_admin_referer( 'denves-lite-dismiss-action' ) ) {

				update_option( 'denves-lite-is-dismissed-admin-notice', intval($_GET['denves-lite-dismiss']) );
				remove_action( 'admin_notices', array(&$this, 'admin_notice') );

			}

		}

		/**
		 * Admin notice.
		 */

		public function admin_notice() {

		?>

            <div class="notice notice-warning is-dismissible">

				<p>
				
					<strong>

						<?php esc_html_e( 'Unlock all premium features of Denves theme like...', 'denves-lite' );  ?>
					
					</strong>
				
				</p>
				
				<p class="notice-coupon-message">

					<span class="dashicon dashicons dashicons-yes-alt" size="10"></span><?php esc_html_e( '600+ Google Fonts', 'denves-lite' ); ?><br/>
					<span class="dashicon dashicons dashicons-yes-alt" size="10"></span><?php esc_html_e( 'Custom colors', 'denves-lite' ); ?><br/>
					<span class="dashicon dashicons dashicons-yes-alt" size="10"></span><?php esc_html_e( 'Portfolio section', 'denves-lite' ); ?><br/>
					<span class="dashicon dashicons dashicons-yes-alt" size="10"></span><?php esc_html_e( 'Unlimited widget areas', 'denves-lite' ); ?><br/>
				
				</p>

				<p>
					<strong><?php esc_html_e( 'Get the premium version of Denves (Starting at €25)', 'denves-lite' ); ?></strong> <br/>
					<strong><?php esc_html_e( 'Or choose the Plus plan to use Denves as a starter theme to build your website.', 'denves-lite' ); ?></strong>
                </p>

            	<p>

					<a href="<?php echo esc_url(admin_url( 'themes.php?page=denves-lite-welcome-page&section=free_pro' )); ?>" class="button"><?php esc_html_e( 'Free vs Pro', 'denves-lite' ); ?></a>
                    <a target="_blank" href="<?php echo esc_url( 'https://www.themeinprogress.com/denves-clean-and-modern-news-and-magazine-wordpress-and-woocommerce-theme/?ref=2&campaign=denves-lite-notice' ); ?>" class="button button-primary"><?php esc_html_e( 'Upgrade Now', 'denves-lite' ); ?></a>

            	</p>

                <p>

                    <?php

                        printf(
                            '<a href="%1$s" class="dismiss-notice">' . esc_html__( 'Dismiss this notice', 'denves-lite' ) . '</a>',
                            esc_url( wp_nonce_url( add_query_arg( 'denves-lite-dismiss', '1' ), 'denves-lite-dismiss-action'))
                        );

                    ?>

            	</p>

            </div>

		<?php

		}

	}

}

new denves_lite_admin_notice();

?>